You are viewing a plain text version of this content. The canonical link for it is here.
Posted to github@datafusion.apache.org by "findepi (via GitHub)" <gi...@apache.org> on 2024/10/15 14:56:54 UTC
Re: [PR] Optimize performance of `math::trunc` (~2.5x faster) [datafusion]
findepi commented on code in PR #12909:
URL: https://github.com/apache/datafusion/pull/12909#discussion_r1801353087
##########
datafusion/functions/src/math/trunc.rs:
##########
@@ -111,44 +111,66 @@ fn trunc(args: &[ArrayRef]) -> Result<ArrayRef> {
);
}
- //if only one arg then invoke toolchain trunc(num) and precision = 0 by default
- //or then invoke the compute_truncate method to process precision
+ // If only one arg then invoke toolchain trunc(num) and precision = 0 by default
+ // or then invoke the compute_truncate method to process precision
let num = &args[0];
let precision = if args.len() == 1 {
ColumnarValue::Scalar(Int64(Some(0)))
} else {
ColumnarValue::Array(Arc::clone(&args[1]))
};
- match args[0].data_type() {
+ match num.data_type() {
Float64 => match precision {
- ColumnarValue::Scalar(Int64(Some(0))) => Ok(Arc::new(
- make_function_scalar_inputs!(num, "num", Float64Array, { f64::trunc }),
- ) as ArrayRef),
- ColumnarValue::Array(precision) => Ok(Arc::new(make_function_inputs2!(
Review Comment:
I've broadened https://github.com/apache/datafusion/issues/12923 to cover this too
--
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For queries about this service, please contact Infrastructure at:
users@infra.apache.org
---------------------------------------------------------------------
To unsubscribe, e-mail: github-unsubscribe@datafusion.apache.org
For additional commands, e-mail: github-help@datafusion.apache.org